@@ -1,19 +1,19 @@
 """Defines common errors raised from database backend code."""
 
 
-class UnsupportedBackend(Exception):
+class UnsupportedBackendError(Exception):
     """Raised when an unsupported backend is specified."""
 
     pass
 
 
 class ConfigurationError(Exception):
-    """Raised when theres a backend configuration connection error."""
+    """Raised when there is a backend configuration connection error."""
 
     pass
 
 
-class BackendEngineNotInstalled(Exception):
+class BackendNotInstalledError(Exception):
     """Raised when a backend engine is not installed."""
 
     pass
